@@ -26,15 +26,17 @@ usage() {
     echo "            [-d **xenial**/**7** | trusty | <other release id> ]"
     echo "            [-e]"
     echo "            [-h]"
-    echo "            [-i **ubuntu** | fedora | centos | rhel ]"
+    echo "            [-i **ubuntu-minimal** | fedora | centos | rhel ]"
+    echo "            [-l <log file> ]"
     echo "            [-n]"
     echo "            [-o **amphora-x64-haproxy** | <filename> ]"
     echo "            [-p]"
     echo "            [-r <root password> ]"
     echo "            [-s **2** | <size in GB> ]"
-    echo "            [-t **qcow2** | tar | vhd ]"
+    echo "            [-t **qcow2** | tar | vhd | raw ]"
     echo "            [-v]"
     echo "            [-w <working directory> ]"
+    echo "            [-x]"
     echo
     echo "        '-a' is the architecture type for the image (default: amd64)"
     echo "        '-b' is the backend type (default: haproxy)"
@@ -43,6 +45,7 @@ usage() {
     echo "        '-e' enable complete mandatory access control systems when available (default: permissive)"
     echo "        '-h' display this help message"
     echo "        '-i' is the base OS (default: ubuntu)"
+    echo "        '-l' is output logfile (default: none)"
     echo "        '-n' disable sshd (default: enabled)"
     echo "        '-o' is the output image file name"
     echo "        '-p' install amphora-agent from distribution packages (default: disabled)"
@@ -80,7 +83,9 @@ if [ -z $OCTAVIA_REPO_PATH ]; then
 fi
 dib_enable_tracing=
 
-while getopts "a:b:c:d:ehi:no:pt:r:s:vw:x" opt; do
+AMP_LOGFILE=""
+
+while getopts "a:b:c:d:ehi:l:no:pt:r:s:vw:x" opt; do
     case $opt in
         a)
             AMP_ARCH=$OPTARG
@@ -114,18 +119,30 @@ while getopts "a:b:c:d:ehi:no:pt:r:s:vw:x" opt; do
         i)
             AMP_BASEOS=$OPTARG
             if [ $AMP_BASEOS != "ubuntu" ] && \
+                [ $AMP_BASEOS != "ubuntu-minimal" ] && \
                 [ $AMP_BASEOS != "fedora" ] && \
                 [ $AMP_BASEOS != "centos" ] && \
                 [ $AMP_BASEOS != "rhel" ]; then
                 echo "Error: Unsupported base OS " $AMP_BASEOS " specified"
                 exit 3
             fi
+            if [ $AMP_BASEOS == "ubuntu" ]; then
+                AMP_BASEOS="ubuntu-minimal"
+            fi
+        ;;
+        l)
+            AMP_LOGFILE="--logfile=$OPTARG"
         ;;
         n)
             AMP_DISABLE_SSHD=1
         ;;
         o)
             AMP_OUTPUTFILENAME=$(readlink -f $OPTARG)
+	    amp_dir=$(dirname $AMP_OUTPUTFILENAME)
+            if [ ! -d $amp_dir ]; then
+                echo "Error: Directory $amp_dir does not exist"
+                exit 3
+            fi
         ;;
         p)
             AMP_PACKAGE_INSTALL=1
@@ -144,7 +161,8 @@ while getopts "a:b:c:d:ehi:no:pt:r:s:vw:x" opt; do
             AMP_IMAGETYPE=$OPTARG
             if [ $AMP_IMAGETYPE != "qcow2" ] && \
                 [ $AMP_IMAGETYPE != "tar" ] && \
-                [ $AMP_IMAGETYPE != "vhd" ]; then
+                [ $AMP_IMAGETYPE != "vhd" ] && \
+                [ $AMP_IMAGETYPE != "raw" ]; then
                 echo "Error: Unsupported image type " $AMP_IMAGETYPE " specified"
                 exit 3
             fi
@@ -175,12 +193,14 @@ AMP_BACKEND=${AMP_BACKEND:-"haproxy-octavia"}
 
 AMP_CACHEDIR=${AMP_CACHEDIR:-"$HOME/.cache/image-create"}
 
-AMP_BASEOS=${AMP_BASEOS:-"ubuntu"}
+AMP_BASEOS=${AMP_BASEOS:-"ubuntu-minimal"}
 
-if [ "$AMP_BASEOS" = "ubuntu" ]; then
+if [ "$AMP_BASEOS" = "ubuntu-minimal" ]; then
     export DIB_RELEASE=${AMP_DIB_RELEASE:-"xenial"}
 elif [ "${AMP_BASEOS}" = "centos" ] || [ "${AMP_BASEOS}" = "rhel" ]; then
     export DIB_RELEASE=${AMP_DIB_RELEASE:-"7"}
+elif [ "${AMP_BASEOS}" = "fedora" ]; then
+    export DIB_RELEASE=${AMP_DIB_RELEASE:-"28"}
 fi
 
 AMP_OUTPUTFILENAME=${AMP_OUTPUTFILENAME:-"$PWD/amphora-x64-haproxy"}
@@ -195,7 +215,7 @@ AMP_PACKAGE_INSTALL=${AMP_PACKAGE_INSTALL:-0}
 
 AMP_ENABLE_FULL_MAC_SECURITY=${AMP_ENABLE_FULL_MAC_SECURITY:-0}
 
-if [ "$AMP_BASEOS" = "rhel" -o "$AMP_BASEOS" = "centos" ] && [ "$AMP_IMAGESIZE" -lt 3 ]; then
+if [ "$AMP_BASEOS" = "rhel" -o "$AMP_BASEOS" = "centos" -o "$AMP_BASEOS" = "fedora" ] && [ "$AMP_IMAGESIZE" -lt 3 ]; then
     echo "RHEL/centos based amphora requires an image size of at least 3GB"
     exit 1
 fi
@@ -274,7 +294,7 @@ if [ "$platform" = 'NAME="Ubuntu"' ]; then
 
     # Also check if we can build the BASEOS on this Ubuntu version
     UBUNTU_VERSION=`lsb_release -r | awk '{print $2}'`
-    if [ "$AMP_BASEOS" != "ubuntu" ] && \
+    if [ "$AMP_BASEOS" != "ubuntu-minimal" ] && \
         [ 1 -eq $(echo "$UBUNTU_VERSION < 14.04" | bc) ]; then
             echo "Ubuntu minimum version 14.04 required to build $AMP_BASEOS."
             echo "Earlier versions don't support the extended attributes required."
@@ -293,10 +313,10 @@ elif [[ $platform =~ "SUSE" ]]; then
 else
     # fedora/centos/rhel
     # Actual qemu-img name may be qemu-img, qemu-img-ev, qemu-img-rhev, ...
-    # "yum install qemu-img" works for all, but search requires wildcard
+    # "dnf|yum install qemu-img" works for all, but search requires wildcard
     PKG_LIST="qemu-img* git"
     for pkg in $PKG_LIST; do
-        if ! yum info installed $pkg &> /dev/null; then
+        if ! rpm -qa $pkg ; then
             echo "Required package " ${pkg/\*} " is not installed.  Exiting."
             exit 1
         fi
@@ -338,6 +358,7 @@ fi
 AMP_element_sequence="$AMP_element_sequence rebind-sshd"
 AMP_element_sequence="$AMP_element_sequence no-resolvconf"
 AMP_element_sequence="$AMP_element_sequence amphora-agent"
+AMP_element_sequence="$AMP_element_sequence sos"
 
 if [ "$AMP_ENABLE_FULL_MAC_SECURITY" -ne 1 ]; then
     # SELinux systems
@@ -348,6 +369,7 @@ fi
 
 # Add keepalived-octavia element
 AMP_element_sequence="$AMP_element_sequence keepalived-octavia"
+AMP_element_sequence="$AMP_element_sequence ipvsadmin"
 
 # Add pip-cache element
 AMP_element_sequence="$AMP_element_sequence pip-cache"
@@ -371,7 +393,7 @@ fi
 
 # Build the image
 
-if [ "$AMP_BASEOS" = "ubuntu" ]; then
+if [ "$AMP_BASEOS" = "ubuntu-minimal" ]; then
     export DIB_CLOUD_INIT_DATASOURCES=$CLOUD_INIT_DATASOURCES
 fi
 
@@ -380,7 +402,7 @@ if [ -n "$dib_enable_tracing" ]; then
     dib_trace_arg="-x"
 fi
 
-disk-image-create $dib_trace_arg -a $AMP_ARCH -o $AMP_OUTPUTFILENAME -t $AMP_IMAGETYPE --image-size $AMP_IMAGESIZE --image-cache $AMP_CACHEDIR $AMP_element_sequence
+disk-image-create $AMP_LOGFILE $dib_trace_arg -a $AMP_ARCH -o $AMP_OUTPUTFILENAME -t $AMP_IMAGETYPE --image-size $AMP_IMAGESIZE --image-cache $AMP_CACHEDIR $AMP_element_sequence
 
 popd > /dev/null # out of $TEMP
 rm -rf $TEMP
