@@ -17,7 +17,6 @@ from wsme import types as wtypes
 from octavia.api.common import types
 from octavia.api.v2.types import listener
 from octavia.api.v2.types import pool
-from octavia.common import constants
 
 
 class BaseLoadBalancerType(types.BaseType):
@@ -53,8 +52,9 @@ class LoadBalancerResponse(BaseLoadBalancerType):
     listeners = wtypes.wsattr([types.IdOnlyType])
     pools = wtypes.wsattr([types.IdOnlyType])
     provider = wtypes.wsattr(wtypes.StringType())
-    flavor_id = wtypes.wsattr(wtypes.StringType())
+    flavor_id = wtypes.wsattr(wtypes.UuidType())
     vip_qos_policy_id = wtypes.wsattr(wtypes.UuidType())
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType()))
 
     @classmethod
     def from_data_model(cls, data_model, children=False):
@@ -77,8 +77,6 @@ class LoadBalancerResponse(BaseLoadBalancerType):
         result.pools = [
             pool_model.from_data_model(i) for i in data_model.pools]
 
-        if not result.flavor_id:
-            result.flavor_id = ""
         if not result.provider:
             result.provider = "octavia"
 
@@ -121,12 +119,9 @@ class LoadBalancerPOST(BaseLoadBalancerType):
     project_id = wtypes.wsattr(wtypes.StringType(max_length=36))
     listeners = wtypes.wsattr([listener.ListenerSingleCreate], default=[])
     pools = wtypes.wsattr([pool.PoolSingleCreate], default=[])
-    # TODO(johnsom) This should be dynamic based on the loaded providers
-    #               once providers are implemented.
-    provider = wtypes.wsattr(wtypes.Enum(str, *constants.SUPPORTED_PROVIDERS))
-    # TODO(johnsom) This should be dynamic based on the loaded flavors
-    #               once flavors are implemented.
-    flavor_id = wtypes.wsattr(wtypes.Enum(str, *constants.SUPPORTED_FLAVORS))
+    provider = wtypes.wsattr(wtypes.StringType(max_length=64))
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(max_length=255)))
+    flavor_id = wtypes.wsattr(wtypes.UuidType())
 
 
 class LoadBalancerRootPOST(types.BaseType):
@@ -140,6 +135,7 @@ class LoadBalancerPUT(BaseLoadBalancerType):
     description = wtypes.wsattr(wtypes.StringType(max_length=255))
     vip_qos_policy_id = wtypes.wsattr(wtypes.UuidType())
     admin_state_up = wtypes.wsattr(bool)
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(max_length=255)))
 
 
 class LoadBalancerRootPUT(types.BaseType):
