@@ -14,17 +14,28 @@
 
 import sys
 
-import eventlet
-eventlet.monkey_patch()
-from oslo_log import log as logging
+import cotyledon
+from cotyledon import oslo_config_glue
+from oslo_config import cfg
+from oslo_reports import guru_meditation_report as gmr
 
-from octavia.common import service
+from octavia.common import service as octavia_service
 from octavia.controller.queue import consumer
+from octavia import version
 
-LOG = logging.getLogger(__name__)
+CONF = cfg.CONF
 
 
 def main():
-    service.prepare_service(sys.argv)
-    c = consumer.Consumer()
-    c.listen()
+    octavia_service.prepare_service(sys.argv)
+
+    gmr.TextGuruMeditation.setup_autorun(version)
+
+    sm = cotyledon.ServiceManager()
+    sm.add(consumer.ConsumerService, workers=CONF.controller_worker.workers,
+           args=(CONF,))
+    oslo_config_glue.setup(sm, CONF, reload_method="mutate")
+    sm.run()
+
+if __name__ == "__main__":
+    main()
