@@ -290,6 +290,8 @@ AMPHORA_INDEX = 'amphora_index'
 FAILOVER_AMPHORA_ID = 'failover_amphora_id'
 DELTA = 'delta'
 DELTAS = 'deltas'
+DESCRIPTION = 'description'
+FIELDS = 'fields'
 HEALTH_MON = 'health_mon'
 HEALTH_MONITOR = 'health_monitor'
 LISTENER = 'listener'
