@@ -31,6 +31,10 @@ class BaseDataModel(object):
             if attr.startswith('_') or not kwargs.get(attr, True):
                 continue
             value = self.__dict__[attr]
+            if attr == 'tags':
+                # tags is a list, it doesn't need recurse
+                ret[attr] = value
+                continue
 
             if recurse:
                 if isinstance(getattr(self, attr), list):
@@ -40,7 +44,8 @@ class BaseDataModel(object):
                             if type(self) not in calling_classes:
                                 ret[attr].append(
                                     item.to_dict(calling_classes=(
-                                        calling_classes + [type(self)])))
+                                        calling_classes + [type(self)]),
+                                        recurse=recurse))
                             else:
                                 ret[attr] = None
                         else:
@@ -48,7 +53,8 @@ class BaseDataModel(object):
                 elif isinstance(getattr(self, attr), BaseDataModel):
                     if type(self) not in calling_classes:
                         ret[attr] = value.to_dict(
-                            calling_classes=calling_classes + [type(self)])
+                            calling_classes=calling_classes + [type(self)],
+                            recurse=recurse)
                     else:
                         ret[attr] = None
                 elif six.PY2 and isinstance(value, six.text_type):
@@ -149,11 +155,14 @@ class BaseDataModel(object):
 class SessionPersistence(BaseDataModel):
 
     def __init__(self, pool_id=None, type=None, cookie_name=None,
-                 pool=None):
+                 pool=None, persistence_timeout=None,
+                 persistence_granularity=None):
         self.pool_id = pool_id
         self.type = type
         self.cookie_name = cookie_name
         self.pool = pool
+        self.persistence_timeout = persistence_timeout
+        self.persistence_granularity = persistence_granularity
 
     def delete(self):
         self.pool.session_persistence = None
@@ -222,7 +231,8 @@ class HealthMonitor(BaseDataModel):
                  rise_threshold=None, http_method=None, url_path=None,
                  expected_codes=None, enabled=None, pool=None, name=None,
                  provisioning_status=None, operating_status=None,
-                 created_at=None, updated_at=None):
+                 created_at=None, updated_at=None, tags=None,
+                 http_version=None, domain_name=None):
         self.id = id
         self.project_id = project_id
         self.pool_id = pool_id
@@ -241,6 +251,9 @@ class HealthMonitor(BaseDataModel):
         self.name = name
         self.created_at = created_at
         self.updated_at = updated_at
+        self.tags = tags
+        self.http_version = http_version
+        self.domain_name = domain_name
 
     def delete(self):
         self.pool.health_monitor = None
@@ -252,7 +265,10 @@ class Pool(BaseDataModel):
                  operating_status=None, members=None, health_monitor=None,
                  session_persistence=None, load_balancer_id=None,
                  load_balancer=None, listeners=None, l7policies=None,
-                 created_at=None, updated_at=None, provisioning_status=None):
+                 created_at=None, updated_at=None, provisioning_status=None,
+                 tags=None, tls_certificate_id=None,
+                 ca_tls_certificate_id=None, crl_container_id=None,
+                 tls_enabled=None):
         self.id = id
         self.project_id = project_id
         self.name = name
@@ -271,6 +287,11 @@ class Pool(BaseDataModel):
         self.created_at = created_at
         self.updated_at = updated_at
         self.provisioning_status = provisioning_status
+        self.tags = tags
+        self.tls_certificate_id = tls_certificate_id
+        self.ca_tls_certificate_id = ca_tls_certificate_id
+        self.crl_container_id = crl_container_id
+        self.tls_enabled = tls_enabled
 
     def update(self, update_dict):
         for key, value in update_dict.items():
@@ -313,16 +334,18 @@ class Pool(BaseDataModel):
 class Member(BaseDataModel):
 
     def __init__(self, id=None, project_id=None, pool_id=None, ip_address=None,
-                 protocol_port=None, weight=None, enabled=None,
+                 protocol_port=None, weight=None, backup=None, enabled=None,
                  subnet_id=None, operating_status=None, pool=None,
                  created_at=None, updated_at=None, provisioning_status=None,
-                 name=None, monitor_address=None, monitor_port=None):
+                 name=None, monitor_address=None, monitor_port=None,
+                 tags=None):
         self.id = id
         self.project_id = project_id
         self.pool_id = pool_id
         self.ip_address = ip_address
         self.protocol_port = protocol_port
         self.weight = weight
+        self.backup = backup
         self.enabled = enabled
         self.subnet_id = subnet_id
         self.operating_status = operating_status
@@ -333,6 +356,7 @@ class Member(BaseDataModel):
         self.name = name
         self.monitor_address = monitor_address
         self.monitor_port = monitor_port
+        self.tags = tags
 
     def delete(self):
         for mem in self.pool.members:
@@ -350,7 +374,11 @@ class Listener(BaseDataModel):
                  tls_certificate_id=None, stats=None, default_pool=None,
                  load_balancer=None, sni_containers=None, peer_port=None,
                  l7policies=None, pools=None, insert_headers=None,
-                 created_at=None, updated_at=None):
+                 created_at=None, updated_at=None,
+                 timeout_client_data=None, timeout_member_connect=None,
+                 timeout_member_data=None, timeout_tcp_inspect=None,
+                 tags=None, client_ca_tls_certificate_id=None,
+                 client_authentication=None, client_crl_container_id=None):
         self.id = id
         self.project_id = project_id
         self.name = name
@@ -374,6 +402,14 @@ class Listener(BaseDataModel):
         self.pools = pools or []
         self.created_at = created_at
         self.updated_at = updated_at
+        self.timeout_client_data = timeout_client_data
+        self.timeout_member_connect = timeout_member_connect
+        self.timeout_member_data = timeout_member_data
+        self.timeout_tcp_inspect = timeout_tcp_inspect
+        self.tags = tags
+        self.client_ca_tls_certificate_id = client_ca_tls_certificate_id
+        self.client_authentication = client_authentication
+        self.client_crl_container_id = client_crl_container_id
 
     def update(self, update_dict):
         for key, value in update_dict.items():
@@ -382,11 +418,13 @@ class Listener(BaseDataModel):
                 if self.default_pool is not None:
                     l7_pool_ids = [p.redirect_pool_id for p in self.l7policies
                                    if p.redirect_pool_id is not None and
-                                   len(p.l7rules) > 0 and p.enabled is True]
+                                   p.l7rules and p.enabled is True]
                     old_pool = self.default_pool
                     if old_pool.id not in l7_pool_ids:
-                        self.pools.remove(old_pool)
-                        old_pool.listeners.remove(self)
+                        if old_pool in self.pools:
+                            self.pools.remove(old_pool)
+                        if self in old_pool.listeners:
+                            old_pool.listeners.remove(self)
                 if value is not None:
                     pool = self._find_in_graph('Pool' + value)
                     if pool not in self.pools:
@@ -412,7 +450,8 @@ class LoadBalancer(BaseDataModel):
                  provisioning_status=None, operating_status=None, enabled=None,
                  topology=None, vip=None, listeners=None, amphorae=None,
                  pools=None, vrrp_group=None, server_group_id=None,
-                 created_at=None, updated_at=None):
+                 created_at=None, updated_at=None, provider=None, tags=None,
+                 flavor_id=None):
 
         self.id = id
         self.project_id = project_id
@@ -430,6 +469,9 @@ class LoadBalancer(BaseDataModel):
         self.server_group_id = server_group_id
         self.created_at = created_at
         self.updated_at = updated_at
+        self.provider = provider
+        self.tags = tags or []
+        self.flavor_id = flavor_id
 
     def update(self, update_dict):
         for key, value in update_dict.items():
@@ -461,7 +503,7 @@ class Vip(BaseDataModel):
 
     def __init__(self, load_balancer_id=None, ip_address=None,
                  subnet_id=None, network_id=None, port_id=None,
-                 load_balancer=None, qos_policy_id=None):
+                 load_balancer=None, qos_policy_id=None, octavia_owned=None):
         self.load_balancer_id = load_balancer_id
         self.ip_address = ip_address
         self.subnet_id = subnet_id
@@ -469,6 +511,7 @@ class Vip(BaseDataModel):
         self.port_id = port_id
         self.load_balancer = load_balancer
         self.qos_policy_id = qos_policy_id
+        self.octavia_owned = octavia_owned
 
 
 class SNI(BaseDataModel):
@@ -500,7 +543,8 @@ class Amphora(BaseDataModel):
                  ha_ip=None, vrrp_port_id=None, ha_port_id=None,
                  load_balancer=None, role=None, cert_expiration=None,
                  cert_busy=False, vrrp_interface=None, vrrp_id=None,
-                 vrrp_priority=None, cached_zone=None):
+                 vrrp_priority=None, cached_zone=None, created_at=None,
+                 updated_at=None, image_id=None, compute_flavor=None):
         self.id = id
         self.load_balancer_id = load_balancer_id
         self.compute_id = compute_id
@@ -518,6 +562,10 @@ class Amphora(BaseDataModel):
         self.cert_expiration = cert_expiration
         self.cert_busy = cert_busy
         self.cached_zone = cached_zone
+        self.created_at = created_at
+        self.updated_at = updated_at
+        self.image_id = image_id
+        self.compute_flavor = compute_flavor
 
     def delete(self):
         for amphora in self.load_balancer.amphorae:
@@ -539,7 +587,7 @@ class L7Rule(BaseDataModel):
     def __init__(self, id=None, l7policy_id=None, type=None, enabled=None,
                  compare_type=None, key=None, value=None, l7policy=None,
                  invert=False, provisioning_status=None, operating_status=None,
-                 project_id=None, created_at=None, updated_at=None):
+                 project_id=None, created_at=None, updated_at=None, tags=None):
         self.id = id
         self.l7policy_id = l7policy_id
         self.type = type
@@ -554,6 +602,7 @@ class L7Rule(BaseDataModel):
         self.created_at = created_at
         self.updated_at = updated_at
         self.enabled = enabled
+        self.tags = tags
 
     def delete(self):
         if len(self.l7policy.l7rules) == 1:
@@ -574,7 +623,8 @@ class L7Policy(BaseDataModel):
                  position=None, listener=None, redirect_pool=None,
                  enabled=None, l7rules=None, provisioning_status=None,
                  operating_status=None, project_id=None, created_at=None,
-                 updated_at=None):
+                 updated_at=None, redirect_prefix=None, tags=None,
+                 redirect_http_code=None):
         self.id = id
         self.name = name
         self.description = description
@@ -592,6 +642,9 @@ class L7Policy(BaseDataModel):
         self.project_id = project_id
         self.created_at = created_at
         self.updated_at = updated_at
+        self.redirect_prefix = redirect_prefix
+        self.tags = tags
+        self.redirect_http_code = redirect_http_code
 
     def _conditionally_remove_pool_links(self, pool):
         """Removes links to the given pool from parent objects.
@@ -606,7 +659,7 @@ class L7Policy(BaseDataModel):
             listener_l7pools = [
                 p.redirect_pool for p in self.listener.l7policies
                 if p.redirect_pool is not None and
-                len(p.l7rules) > 0 and p.enabled is True and
+                p.l7rules and p.enabled is True and
                 p.id != self.id]
             if pool not in listener_l7pools:
                 self.listener.pools.remove(pool)
@@ -618,9 +671,10 @@ class L7Policy(BaseDataModel):
                 self._conditionally_remove_pool_links(self.redirect_pool)
                 self.action = constants.L7POLICY_ACTION_REDIRECT_TO_POOL
                 self.redirect_url = None
+                self.redirect_http_code = None
                 pool = self._find_in_graph('Pool' + value)
                 self.redirect_pool = pool
-                if len(self.l7rules) > 0 and (self.enabled is True or (
+                if self.l7rules and (self.enabled is True or (
                         'enabled' in update_dict.keys() and
                         update_dict['enabled'] is True)):
                     if pool not in self.listener.pools:
@@ -637,6 +691,7 @@ class L7Policy(BaseDataModel):
                 self._conditionally_remove_pool_links(self.redirect_pool)
                 self.redirect_pool = None
                 self.redirect_pool_id = None
+                self.redirect_http_code = None
             elif key == 'position':
                 self.listener.l7policies.remove(self)
                 self.listener.l7policies.insert(value - 1, self)
@@ -644,7 +699,7 @@ class L7Policy(BaseDataModel):
                 if (value is True and self.action ==
                         constants.L7POLICY_ACTION_REDIRECT_TO_POOL and
                         self.redirect_pool is not None and
-                        len(self.l7rules) > 0 and
+                        self.l7rules and
                         self.redirect_pool not in self.listener.pools):
                     self.listener.pools.append(self.redirect_pool)
                     self.redirect_pool.listeners.append(self.listener)
@@ -692,3 +747,25 @@ class Quotas(BaseDataModel):
         self.in_use_load_balancer = in_use_load_balancer
         self.in_use_member = in_use_member
         self.in_use_pool = in_use_pool
+
+
+class Flavor(BaseDataModel):
+
+    def __init__(self, id=None, name=None,
+                 description=None, enabled=None,
+                 flavor_profile_id=None):
+        self.id = id
+        self.name = name
+        self.description = description
+        self.enabled = enabled
+        self.flavor_profile_id = flavor_profile_id
+
+
+class FlavorProfile(BaseDataModel):
+
+    def __init__(self, id=None, name=None, provider_name=None,
+                 flavor_data=None):
+        self.id = id
+        self.name = name
+        self.provider_name = provider_name
+        self.flavor_data = flavor_data
