@@ -81,15 +81,13 @@ class JinjaTemplater(object):
         self.log_server = log_server
         self.connection_logging = connection_logging
 
-    def build_config(self, host_amphora, listeners, tls_certs,
-                     haproxy_versions, socket_path=None,
-                     client_ca_filename=None, client_crl=None,
-                     pool_tls_certs=None):
+    def build_config(self, host_amphora, listeners, haproxy_versions,
+                     socket_path=None, client_ca_filename=None,
+                     client_crl=None, pool_tls_certs=None):
         """Convert a logical configuration to the HAProxy version
 
         :param host_amphora: The Amphora this configuration is hosted on
         :param listener: The listener configuration
-        :param tls_certs: Dict of the TLS certificates for the listeners
         :param socket_path: The socket path for Haproxy process
         :return: Rendered configuration
         """
@@ -104,8 +102,7 @@ class JinjaTemplater(object):
             feature_compatibility[constants.HTTP_REUSE] = True
 
         return self.render_loadbalancer_obj(
-            host_amphora, listeners, tls_certs=tls_certs,
-            socket_path=socket_path,
+            host_amphora, listeners, socket_path=socket_path,
             feature_compatibility=feature_compatibility,
             client_ca_filename=client_ca_filename, client_crl=client_crl,
             pool_tls_certs=pool_tls_certs)
@@ -125,15 +122,13 @@ class JinjaTemplater(object):
         return JINJA_ENV.get_template(os.path.basename(self.haproxy_template))
 
     def render_loadbalancer_obj(self, host_amphora, listeners,
-                                tls_certs=None, socket_path=None,
-                                feature_compatibility=None,
+                                socket_path=None, feature_compatibility=None,
                                 client_ca_filename=None, client_crl=None,
                                 pool_tls_certs=None):
         """Renders a templated configuration from a load balancer object
 
         :param host_amphora: The Amphora this configuration is hosted on
         :param listener: The listener configuration
-        :param tls_certs: Dict of the TLS certificates for the listener
         :param client_ca_filename: The CA certificate for client authorization
         :param socket_path: The socket path for Haproxy process
         :return: Rendered configuration
@@ -143,7 +138,6 @@ class JinjaTemplater(object):
             host_amphora,
             listeners[0].load_balancer,
             listeners,
-            tls_certs,
             feature_compatibility,
             client_ca_filename=client_ca_filename,
             client_crl=client_crl,
@@ -160,9 +154,8 @@ class JinjaTemplater(object):
             constants=constants)
 
     def _transform_loadbalancer(self, host_amphora, loadbalancer, listeners,
-                                tls_certs, feature_compatibility,
-                                client_ca_filename=None, client_crl=None,
-                                pool_tls_certs=None):
+                                feature_compatibility, client_ca_filename=None,
+                                client_crl=None, pool_tls_certs=None):
         """Transforms a load balancer into an object that will
 
            be processed by the templating system
@@ -172,7 +165,7 @@ class JinjaTemplater(object):
             if listener.protocol == constants.PROTOCOL_UDP:
                 continue
             listener_transforms.append(self._transform_listener(
-                listener, tls_certs, feature_compatibility, loadbalancer,
+                listener, feature_compatibility, loadbalancer,
                 client_ca_filename=client_ca_filename, client_crl=client_crl,
                 pool_tls_certs=pool_tls_certs))
 
@@ -224,7 +217,7 @@ class JinjaTemplater(object):
             'vrrp_priority': amphora.vrrp_priority
         }
 
-    def _transform_listener(self, listener, tls_certs, feature_compatibility,
+    def _transform_listener(self, listener, feature_compatibility,
                             loadbalancer, client_ca_filename=None,
                             client_crl=None, pool_tls_certs=None):
         """Transforms a listener into an object that will
@@ -254,14 +247,12 @@ class JinjaTemplater(object):
             ret_value['connection_limit'] = listener.connection_limit
         else:
             ret_value['connection_limit'] = constants.HAPROXY_MAX_MAXCONN
-        if listener.tls_certificate_id and tls_certs is not None:
-            ret_value['default_tls_path'] = '%s.pem' % (
-                os.path.join(self.base_crt_dir,
-                             loadbalancer.id,
-                             tls_certs[listener.tls_certificate_id].id))
-        if listener.sni_containers:
-            ret_value['crt_dir'] = os.path.join(
-                self.base_crt_dir, loadbalancer.id)
+
+        if listener.tls_certificate_id:
+            ret_value['crt_list_filename'] = os.path.join(
+                CONF.haproxy_amphora.base_cert_dir,
+                loadbalancer.id, '{}.pem'.format(listener.id))
+
         if listener.client_ca_tls_certificate_id:
             ret_value['client_ca_tls_path'] = '%s' % (
                 os.path.join(self.base_crt_dir, loadbalancer.id,
