@@ -18,6 +18,7 @@ from oslo_utils import uuidutils
 from octavia.common import constants
 from octavia.common import data_models
 from octavia.compute import compute_base as driver_base
+from octavia.network import data_models as network_models
 
 LOG = logging.getLogger(__name__)
 
@@ -41,11 +42,12 @@ class NoopManager(object):
                   key_name, sec_groups, network_ids, config_drive_files,
                   user_data, port_ids, server_group_id)
         self.computeconfig[(name, amphora_flavor, image_id, image_tag,
-                            image_owner, key_name, user_data)] = (
+                            image_owner, key_name, user_data,
+                            server_group_id)] = (
             name, amphora_flavor,
             image_id, image_tag, image_owner, key_name, sec_groups,
-            network_ids, config_drive_files,
-            user_data, port_ids, 'build')
+            network_ids, config_drive_files, user_data, port_ids,
+            server_group_id, 'build')
         compute_id = uuidutils.generate_uuid()
         return compute_id
 
@@ -80,6 +82,35 @@ class NoopManager(object):
                   self.__class__.__name__, server_group_id)
         self.computeconfig[server_group_id] = (server_group_id, 'delete')
 
+    def attach_network_or_port(self, compute_id, network_id, ip_address=None,
+                               port_id=None):
+        LOG.debug("Compute %s no-op, attach_network_or_port compute_id %s,"
+                  "network_id %s, ip_address %s, port_id %s",
+                  self.__class__.__name__, compute_id,
+                  network_id, ip_address, port_id)
+        self.computeconfig[(compute_id, network_id, ip_address, port_id)] = (
+            compute_id, network_id, ip_address, port_id,
+            'attach_network_or_port')
+        return network_models.Interface(
+            id=uuidutils.generate_uuid(),
+            compute_id=compute_id,
+            network_id=network_id,
+            fixed_ips=[],
+            port_id=uuidutils.generate_uuid()
+        )
+
+    def detach_port(self, compute_id, port_id):
+        LOG.debug("Compute %s no-op, detach_network compute_id %s, "
+                  "port_id %s",
+                  self.__class__.__name__, compute_id, port_id)
+        self.computeconfig[(compute_id, port_id)] = (
+            compute_id, port_id, 'detach_port')
+
+    def validate_flavor(self, flavor_id):
+        LOG.debug("Compute %s no-op, validate_flavor flavor_id %s",
+                  self.__class__.__name__, flavor_id)
+        self.computeconfig[flavor_id] = (flavor_id, 'validate_flavor')
+
 
 class NoopComputeDriver(driver_base.ComputeBase):
     def __init__(self):
@@ -113,3 +144,14 @@ class NoopComputeDriver(driver_base.ComputeBase):
 
     def delete_server_group(self, server_group_id):
         self.driver.delete_server_group(server_group_id)
+
+    def attach_network_or_port(self, compute_id, network_id, ip_address=None,
+                               port_id=None):
+        self.driver.attach_network_or_port(compute_id, network_id, ip_address,
+                                           port_id)
+
+    def detach_port(self, compute_id, port_id):
+        self.driver.detach_port(compute_id, port_id)
+
+    def validate_flavor(self, flavor_id):
+        self.driver.validate_flavor(flavor_id)
