@@ -31,9 +31,9 @@ from octavia.db import models
 from octavia.network import data_models as network_models
 from octavia.tests.unit import base
 from octavia.tests.unit.common.sample_configs import sample_certs
-from octavia.tests.unit.common.sample_configs import sample_configs_combined
+from octavia.tests.unit.common.sample_configs import sample_configs_split
 
-API_VERSION = '1.0'
+API_VERSION = '0.5'
 FAKE_CIDR = '198.51.100.0/24'
 FAKE_GATEWAY = '192.51.100.1'
 FAKE_IP = '192.0.2.10'
@@ -70,26 +70,26 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
             API_VERSION].get_info.return_value = {
             'haproxy_version': u'1.6.3-1ubuntu0.1',
             'api_version': API_VERSION}
-        self.driver.jinja_combo = mock.MagicMock()
+        self.driver.jinja_split = mock.MagicMock()
         self.driver.udp_jinja = mock.MagicMock()
 
         # Build sample Listener and VIP configs
-        self.sl = sample_configs_combined.sample_listener_tuple(
+        self.sl = sample_configs_split.sample_listener_tuple(
             tls=True, sni=True, client_ca_cert=True, client_crl_cert=True,
             recursive_nest=True)
-        self.sl_udp = sample_configs_combined.sample_listener_tuple(
+        self.sl_udp = sample_configs_split.sample_listener_tuple(
             proto=constants.PROTOCOL_UDP,
             persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
             persistence_timeout=33,
             persistence_granularity='255.255.0.0',
             monitor_proto=constants.HEALTH_MONITOR_UDP_CONNECT)
-        self.pool_has_cert = sample_configs_combined.sample_pool_tuple(
+        self.pool_has_cert = sample_configs_split.sample_pool_tuple(
             pool_cert=True, pool_ca_cert=True, pool_crl=True)
         self.amp = self.sl.load_balancer.amphorae[0]
-        self.sv = sample_configs_combined.sample_vip_tuple()
+        self.sv = sample_configs_split.sample_vip_tuple()
         self.lb = self.sl.load_balancer
         self.lb_udp = (
-            sample_configs_combined.sample_lb_with_udp_listener_tuple())
+            sample_configs_split.sample_lb_with_udp_listener_tuple())
         self.fixed_ip = mock.MagicMock()
         self.fixed_ip.ip_address = '198.51.100.5'
         self.fixed_ip.subnet.cidr = '198.51.100.0/24'
@@ -137,34 +137,34 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         mock_load_cert.return_value = {
             'tls_cert': self.sl.default_tls_container, 'sni_certs': [],
             'client_ca_cert': None}
-        self.driver.jinja_combo.build_config.return_value = 'the_config'
+        self.driver.jinja_split.build_config.return_value = 'the_config'
 
         mock_empty_lb = mock.MagicMock()
         mock_empty_lb.listeners = []
         self.driver.update_amphora_listeners(mock_empty_lb, mock_amphora,
                                              self.timeout_dict)
         mock_load_cert.assert_not_called()
-        self.driver.jinja_combo.build_config.assert_not_called()
+        self.driver.jinja_split.build_config.assert_not_called()
         self.driver.clients[API_VERSION].upload_config.assert_not_called()
         self.driver.clients[API_VERSION].reload_listener.assert_not_called()
 
         self.driver.update_amphora_listeners(self.lb,
                                              mock_amphora, self.timeout_dict)
         self.driver.clients[API_VERSION].upload_config.assert_called_once_with(
-            mock_amphora, self.lb.id, 'the_config',
+            mock_amphora, self.sl.id, 'the_config',
             timeout_dict=self.timeout_dict)
         self.driver.clients[API_VERSION].reload_listener(
-            mock_amphora, self.lb.id, timeout_dict=self.timeout_dict)
+            mock_amphora, self.sl.id, timeout_dict=self.timeout_dict)
 
         mock_load_cert.reset_mock()
-        self.driver.jinja_combo.build_config.reset_mock()
+        self.driver.jinja_split.build_config.reset_mock()
         self.driver.clients[API_VERSION].upload_config.reset_mock()
         self.driver.clients[API_VERSION].reload_listener.reset_mock()
         mock_amphora.status = constants.DELETED
         self.driver.update_amphora_listeners(self.lb,
                                              mock_amphora, self.timeout_dict)
         mock_load_cert.assert_not_called()
-        self.driver.jinja_combo.build_config.assert_not_called()
+        self.driver.jinja_split.build_config.assert_not_called()
         self.driver.clients[API_VERSION].upload_config.assert_not_called()
         self.driver.clients[API_VERSION].reload_listener.assert_not_called()
 
@@ -184,19 +184,19 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.clients[API_VERSION].get_cert_md5sum.side_effect = [
             exc.NotFound, 'Fake_MD5', 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa',
             'CA_CERT_MD5']
-        self.driver.jinja_combo.build_config.side_effect = ['fake_config']
+        self.driver.jinja_split.build_config.side_effect = ['fake_config']
 
         # Execute driver method
         self.driver.update(self.lb)
 
         # verify result
         gcm_calls = [
-            mock.call(self.amp, self.lb.id,
+            mock.call(self.amp, self.sl.id,
                       self.sl.default_tls_container.id + '.pem',
                       ignore=(404,)),
-            mock.call(self.amp, self.lb.id,
+            mock.call(self.amp, self.sl.id,
                       sconts[0].id + '.pem', ignore=(404,)),
-            mock.call(self.amp, self.lb.id,
+            mock.call(self.amp, self.sl.id,
                       sconts[1].id + '.pem', ignore=(404,)),
         ]
 
@@ -215,11 +215,11 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
                           sample_certs.X509_IMDS]) + b'\n'
 
         ucp_calls = [
-            mock.call(self.amp, self.lb.id,
+            mock.call(self.amp, self.sl.id,
                       self.sl.default_tls_container.id + '.pem', fp1),
-            mock.call(self.amp, self.lb.id,
+            mock.call(self.amp, self.sl.id,
                       sconts[0].id + '.pem', fp2),
-            mock.call(self.amp, self.lb.id,
+            mock.call(self.amp, self.sl.id,
                       sconts[1].id + '.pem', fp3),
         ]
 
@@ -228,16 +228,16 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
 
         # upload only one config file
         self.driver.clients[API_VERSION].upload_config.assert_called_once_with(
-            self.amp, self.lb.id, 'fake_config', timeout_dict=None)
+            self.amp, self.sl.id, 'fake_config', timeout_dict=None)
         # start should be called once
         self.driver.clients[
             API_VERSION].reload_listener.assert_called_once_with(
-            self.amp, self.lb.id, timeout_dict=None)
+            self.amp, self.sl.id, timeout_dict=None)
         secret_calls = [
             mock.call(self.sl, self.sl.client_ca_tls_certificate_id, self.amp,
-                      self.lb.id),
+                      self.sl.id),
             mock.call(self.sl, self.sl.client_crl_container_id, self.amp,
-                      self.lb.id)
+                      self.sl.id)
         ]
         mock_secret.assert_has_calls(secret_calls)
 
@@ -265,7 +265,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
 
     @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
     def test__process_tls_certificates_no_ca_cert(self, mock_load_crt):
-        sample_listener = sample_configs_combined.sample_listener_tuple(
+        sample_listener = sample_configs_split.sample_listener_tuple(
             tls=True, sni=True)
         sconts = []
         for sni_container in sample_listener.sni_containers:
@@ -275,7 +275,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
             'sni_certs': sconts
         }
         self.driver.clients[API_VERSION].get_cert_md5sum.side_effect = [
-            exc.NotFound, 'Fake_MD5', 'aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa']
+            exc.NotFound, 'Fake_MD5', 'aaaaa', 'aaaaaaaa']
         self.driver._process_tls_certificates(
             sample_listener, self.amp, sample_listener.load_balancer.id)
         gcm_calls = [
@@ -309,14 +309,14 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.clients[API_VERSION].upload_cert_pem.assert_has_calls(
             ucp_calls, any_order=True)
         self.assertEqual(
-            3, self.driver.clients[API_VERSION].upload_cert_pem.call_count)
+            4, self.driver.clients[API_VERSION].upload_cert_pem.call_count)
 
     @mock.patch('oslo_context.context.RequestContext')
     @mock.patch('octavia.amphorae.drivers.haproxy.rest_api_driver.'
                 'HaproxyAmphoraLoadBalancerDriver._upload_cert')
     def test_process_secret(self, mock_upload_cert, mock_oslo):
         # Test bypass if no secret_ref
-        sample_listener = sample_configs_combined.sample_listener_tuple(
+        sample_listener = sample_configs_split.sample_listener_tuple(
             tls=True, sni=True)
 
         result = self.driver._process_secret(sample_listener, None)
@@ -325,7 +325,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.cert_manager.get_secret.assert_not_called()
 
         # Test the secret process
-        sample_listener = sample_configs_combined.sample_listener_tuple(
+        sample_listener = sample_configs_split.sample_listener_tuple(
             tls=True, sni=True, client_ca_cert=True)
         fake_context = 'fake context'
         fake_secret = b'fake cert'
@@ -352,7 +352,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
     @mock.patch('octavia.amphorae.drivers.haproxy.rest_api_driver.'
                 'HaproxyAmphoraLoadBalancerDriver._process_pool_certs')
     def test__process_listener_pool_certs(self, mock_pool_cert):
-        sample_listener = sample_configs_combined.sample_listener_tuple(
+        sample_listener = sample_configs_split.sample_listener_tuple(
             l7=True)
 
         ref_pool_cert_1 = {'client_cert': '/some/fake/cert-1.pem'}
@@ -388,7 +388,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         fake_cert_dir = '/fake/cert/dir'
         conf = oslo_fixture.Config(cfg.CONF)
         conf.config(group="haproxy_amphora", base_cert_dir=fake_cert_dir)
-        sample_listener = sample_configs_combined.sample_listener_tuple(
+        sample_listener = sample_configs_split.sample_listener_tuple(
             pool_cert=True, pool_ca_cert=True, pool_crl=True)
         cert_data_mock = mock.MagicMock()
         cert_data_mock.id = uuidutils.generate_uuid()
@@ -451,7 +451,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.start(loadbalancer)
         self.driver.clients[
             API_VERSION].start_listener.assert_called_once_with(
-            amp1, loadbalancer.id)
+            amp1, listener.id)
 
     def test_start_with_amphora(self):
         # Execute driver method
@@ -461,7 +461,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.start(self.lb, self.amp)
         self.driver.clients[
             API_VERSION].start_listener.assert_called_once_with(
-            self.amp, self.lb.id)
+            self.amp, self.sl.id)
 
         self.driver.clients[API_VERSION].start_listener.reset_mock()
         amp.status = constants.DELETED
@@ -485,10 +485,10 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
                                     mock_secret):
         self.driver.clients[
             API_VERSION].delete_listener.__name__ = 'delete_listener'
-        sl = sample_configs_combined.sample_listener_tuple(
+        sl = sample_configs_split.sample_listener_tuple(
             tls=True, sni=True, client_ca_cert=True, client_crl_cert=True,
             recursive_nest=True)
-        sl2 = sample_configs_combined.sample_listener_tuple(
+        sl2 = sample_configs_split.sample_listener_tuple(
             id='sample_listener_id_2')
         sl.load_balancer.listeners.append(sl2)
         mock_cert.return_value = {'cn': sample_certs.X509_CERT_CN}
@@ -499,114 +499,21 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         mock_load_crt.side_effect = [{
             'tls_cert': self.sl.default_tls_container, 'sni_certs': sconts},
             {'tls_cert': None, 'sni_certs': []}]
-        self.driver.jinja_combo.build_config.side_effect = ['fake_config']
+        self.driver.jinja_split.build_config.side_effect = ['fake_config']
+
         # Execute driver method
         self.driver.delete(sl)
 
-        # All of the pem files should be removed
-        dcp_calls = [
-            mock.call(self.amp, sl.load_balancer.id,
-                      self.sl.default_tls_container.id + '.pem'),
-            mock.call(self.amp, sl.load_balancer.id, sconts[0].id + '.pem'),
-            mock.call(self.amp, sl.load_balancer.id, sconts[1].id + '.pem'),
-        ]
-        self.driver.clients[API_VERSION].delete_cert_pem.assert_has_calls(
-            dcp_calls, any_order=True)
-
-        # Now just make sure we did an update and not a delete
-        self.driver.clients[API_VERSION].delete_listener.assert_not_called()
-        self.driver.clients[API_VERSION].upload_config.assert_called_once_with(
-            self.amp, sl.load_balancer.id, 'fake_config', timeout_dict=None)
-        # start should be called once
+        # Now just make sure we did a delete
         self.driver.clients[
-            API_VERSION].reload_listener.assert_called_once_with(
-            self.amp, sl.load_balancer.id, timeout_dict=None)
-
-    @mock.patch('octavia.amphorae.drivers.haproxy.rest_api_driver.'
-                'HaproxyAmphoraLoadBalancerDriver._process_secret')
-    @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
-    @mock.patch('octavia.common.tls_utils.cert_parser.get_host_names')
-    def test_delete_second_listener_active_standby(self, mock_cert,
-                                                   mock_load_crt,
-                                                   mock_secret):
-        self.driver.clients[
-            API_VERSION].delete_listener.__name__ = 'delete_listener'
-        sl = sample_configs_combined.sample_listener_tuple(
-            tls=True, sni=True, client_ca_cert=True, client_crl_cert=True,
-            recursive_nest=True, topology=constants.TOPOLOGY_ACTIVE_STANDBY)
-        sl2 = sample_configs_combined.sample_listener_tuple(
-            id='sample_listener_id_2',
-            topology=constants.TOPOLOGY_ACTIVE_STANDBY)
-        sl.load_balancer.listeners.append(sl2)
-        mock_cert.return_value = {'cn': sample_certs.X509_CERT_CN}
-        mock_secret.side_effect = ['filename.pem', 'crl-filename.pem',
-                                   'filename.pem', 'crl-filename.pem']
-        sconts = []
-        for sni_container in self.sl.sni_containers:
-            sconts.append(sni_container.tls_container)
-        mock_load_crt.side_effect = [{
-            'tls_cert': self.sl.default_tls_container, 'sni_certs': sconts},
-            {'tls_cert': None, 'sni_certs': []},
-            {'tls_cert': None, 'sni_certs': []},
-            {'tls_cert': None, 'sni_certs': []}]
-        self.driver.jinja_combo.build_config.side_effect = [
-            'fake_config', 'fake_config']
-        # Execute driver method
-        self.driver.delete(sl)
-
-        amp1 = sl.load_balancer.amphorae[0]
-        amp2 = sl.load_balancer.amphorae[1]
-
-        # All of the pem files should be removed (using amp1 or amp2)
-        dcp_calls_list = [
-            [
-                mock.call(amp1, sl.load_balancer.id,
-                          sl.default_tls_container.id + '.pem'),
-                mock.call(amp2, sl.load_balancer.id,
-                          sl.default_tls_container.id + '.pem')
-            ],
-            [
-                mock.call(amp1, sl.load_balancer.id, sconts[0].id + '.pem'),
-                mock.call(amp2, sl.load_balancer.id, sconts[0].id + '.pem')
-            ],
-            [
-                mock.call(amp1, sl.load_balancer.id, sconts[1].id + '.pem'),
-                mock.call(amp2, sl.load_balancer.id, sconts[1].id + '.pem')
-            ]
-        ]
-        mock_calls = (
-            self.driver.clients[API_VERSION].delete_cert_pem.mock_calls)
-        for dcp_calls in dcp_calls_list:
-            # Ensure that at least one call in each pair has been seen
-            if (dcp_calls[0] not in mock_calls and
-                    dcp_calls[1] not in mock_calls):
-                raise Exception("%s not found in %s" % (dcp_calls, mock_calls))
-
-        # Now just make sure we did an update and not a delete
-        self.driver.clients[API_VERSION].delete_listener.assert_not_called()
-        upload_config_calls = [
-            mock.call(amp1, sl.load_balancer.id, 'fake_config',
-                      timeout_dict=None),
-            mock.call(amp2, sl.load_balancer.id, 'fake_config',
-                      timeout_dict=None)
-        ]
-        self.driver.clients[API_VERSION].upload_config.assert_has_calls(
-            upload_config_calls, any_order=True)
-
-        # start should be called once per amp
-        reload_listener_calls = [
-            mock.call(amp1, sl.load_balancer.id, timeout_dict=None),
-            mock.call(amp2, sl.load_balancer.id, timeout_dict=None)
-        ]
-        self.driver.clients[
-            API_VERSION].reload_listener.assert_has_calls(
-                reload_listener_calls, any_order=True)
+            API_VERSION].delete_listener.assert_called_once_with(
+            self.amp, self.sl.id)
 
     @mock.patch('octavia.common.tls_utils.cert_parser.load_certificates_data')
     def test_delete_last_listener(self, mock_load_crt):
         self.driver.clients[
             API_VERSION].delete_listener.__name__ = 'delete_listener'
-        sl = sample_configs_combined.sample_listener_tuple(
+        sl = sample_configs_split.sample_listener_tuple(
             tls=True, sni=True, client_ca_cert=True, client_crl_cert=True,
             recursive_nest=True)
         mock_load_crt.side_effect = [{
@@ -615,7 +522,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
         self.driver.delete(sl)
         self.driver.clients[
             API_VERSION].delete_listener.assert_called_once_with(
-            self.amp, sl.load_balancer.id)
+            self.amp, sl.id)
 
     def test_udp_delete(self):
         self.driver.clients[
@@ -628,7 +535,7 @@ class TestHaproxyAmphoraLoadBalancerDriverTest(base.TestCase):
 
     def test_get_info(self):
         expected_info = {'haproxy_version': '1.6.3-1ubuntu0.1',
-                         'api_version': '1.0'}
+                         'api_version': API_VERSION}
         result = self.driver.get_info(self.amp)
         self.assertEqual(expected_info, result)
 
@@ -754,9 +661,9 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     def setUp(self):
         super(TestAmphoraAPIClientTest, self).setUp()
-        self.driver = driver.AmphoraAPIClient1_0()
+        self.driver = driver.AmphoraAPIClient0_5()
         self.base_url = "https://192.0.2.77:9443/"
-        self.base_url_ver = self.base_url + "1.0"
+        self.base_url_ver = self.base_url + API_VERSION
         self.amp = models.Amphora(lb_network_ip='192.0.2.77', compute_id='123')
         self.amp.api_version = API_VERSION
         self.port_info = dict(mac_address=FAKE_MAC_ADDRESS)
@@ -779,9 +686,9 @@ class TestAmphoraAPIClientTest(base.TestCase):
         url = self.driver._base_url(FAKE_IP)
         self.assertEqual('https://192.0.2.10:9443/', url)
         url = self.driver._base_url(FAKE_IPV6, self.amp.api_version)
-        self.assertEqual('https://[2001:db8::cafe]:9443/1.0/', url)
+        self.assertEqual('https://[2001:db8::cafe]:9443/0.5/', url)
         url = self.driver._base_url(FAKE_IPV6_LLA, self.amp.api_version)
-        self.assertEqual('https://[fe80::00ff:fe00:cafe%o-hm0]:9443/1.0/', url)
+        self.assertEqual('https://[fe80::00ff:fe00:cafe%o-hm0]:9443/0.5/', url)
 
     @mock.patch('requests.Session.get', side_effect=requests.ConnectionError)
     @mock.patch('octavia.amphorae.drivers.haproxy.rest_api_driver.time.sleep')
@@ -798,6 +705,12 @@ class TestAmphoraAPIClientTest(base.TestCase):
         result = self.driver.get_api_version(self.amp)
         self.assertEqual(ref_api_version, result)
 
+    @requests_mock.mock()
+    def test_get_api_version_not_found(self, mock_requests):
+        mock_requests.get('{base}/'.format(base=self.base_url),
+                          status_code=404)
+        self.assertRaises(exc.NotFound, self.driver.get_api_version, self.amp)
+
     @requests_mock.mock()
     def test_get_info(self, m):
         info = {"hostname": "some_hostname", "version": "some_version",
@@ -911,41 +824,41 @@ class TestAmphoraAPIClientTest(base.TestCase):
                           self.driver.get_all_listeners, self.amp)
 
     @requests_mock.mock()
-    def test_start_loadbalancer(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1))
+    def test_start_listener(self, m):
+        m.put("{base}/listeners/{listener_id}/start".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1))
         self.driver.start_listener(self.amp, FAKE_UUID_1)
         self.assertTrue(m.called)
 
     @requests_mock.mock()
-    def test_start_loadbalancer_missing(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1),
+    def test_start_listener_missing(self, m):
+        m.put("{base}/listeners/{listener_id}/start".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1),
             status_code=404,
             headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
-    def test_start_loadbalancer_unauthorized(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1),
+    def test_start_listener_unauthorized(self, m):
+        m.put("{base}/listeners/{listener_id}/start".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1),
             status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
-    def test_start_loadbalancer_server_error(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1),
+    def test_start_listener_server_error(self, m):
+        m.put("{base}/listeners/{listener_id}/start".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1),
             status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
 
     @requests_mock.mock()
-    def test_start_loadbalancer_service_unavailable(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/start".format(
-            base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1),
+    def test_start_listener_service_unavailable(self, m):
+        m.put("{base}/listeners/{listener_id}/start".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1),
             status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.start_listener,
                           self.amp, FAKE_UUID_1)
@@ -992,10 +905,9 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_upload_cert_pem(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME))
+        m.put("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME))
         self.driver.upload_cert_pem(self.amp, FAKE_UUID_1,
                                     FAKE_PEM_FILENAME,
                                     "some_file")
@@ -1003,40 +915,36 @@ class TestAmphoraAPIClientTest(base.TestCase):
 
     @requests_mock.mock()
     def test_upload_invalid_cert_pem(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), status_code=400)
+        m.put("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), status_code=400)
         self.assertRaises(exc.InvalidRequest, self.driver.upload_cert_pem,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME,
                           "some_file")
 
     @requests_mock.mock()
     def test_upload_cert_pem_unauthorized(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), status_code=401)
+        m.put("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.upload_cert_pem,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME,
                           "some_file")
 
     @requests_mock.mock()
     def test_upload_cert_pem_server_error(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), status_code=500)
+        m.put("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.upload_cert_pem,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME,
                           "some_file")
 
     @requests_mock.mock()
     def test_upload_cert_pem_service_unavailable(self, m):
-        m.put("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), status_code=503)
+        m.put("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.upload_cert_pem,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME,
                           "some_file")
@@ -1083,57 +991,51 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_get_cert_5sum(self, m):
         md5sum = {"md5sum": "some_real_sum"}
-        m.get("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), json=md5sum)
+        m.get("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), json=md5sum)
         sum_test = self.driver.get_cert_md5sum(self.amp, FAKE_UUID_1,
                                                FAKE_PEM_FILENAME)
         self.assertIsNotNone(sum_test)
 
     @requests_mock.mock()
     def test_get_cert_5sum_missing(self, m):
-        m.get("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), status_code=404,
-              headers={'content-type': 'application/json'})
+        m.get("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), status_code=404,
+            headers={'content-type': 'application/json'})
         self.assertRaises(exc.NotFound, self.driver.get_cert_md5sum,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME)
 
     @requests_mock.mock()
     def test_get_cert_5sum_unauthorized(self, m):
-        m.get("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), status_code=401)
+        m.get("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.get_cert_md5sum,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME)
 
     @requests_mock.mock()
     def test_get_cert_5sum_server_error(self, m):
-        m.get("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), status_code=500)
+        m.get("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.get_cert_md5sum,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME)
 
     @requests_mock.mock()
     def test_get_cert_5sum_service_unavailable(self, m):
-        m.get("{base}/loadbalancer/{loadbalancer_id}/certificates/"
-              "{filename}".format(
-                  base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
-                  filename=FAKE_PEM_FILENAME), status_code=503)
+        m.get("{base}/listeners/{listener_id}/certificates/{filename}".format(
+            base=self.base_url_ver, listener_id=FAKE_UUID_1,
+            filename=FAKE_PEM_FILENAME), status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.get_cert_md5sum,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME)
 
     @requests_mock.mock()
     def test_delete_cert_pem(self, m):
         m.delete(
-            "{base}/loadbalancer/{loadbalancer_id}/certificates/"
-            "{filename}".format(
-                base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
+            "{base}/listeners/{listener_id}/certificates/{filename}".format(
+                base=self.base_url_ver, listener_id=FAKE_UUID_1,
                 filename=FAKE_PEM_FILENAME))
         self.driver.delete_cert_pem(self.amp, FAKE_UUID_1,
                                     FAKE_PEM_FILENAME)
@@ -1142,9 +1044,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_delete_cert_pem_missing(self, m):
         m.delete(
-            "{base}/loadbalancer/{loadbalancer_id}/certificates/"
-            "{filename}".format(
-                base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
+            "{base}/listeners/{listener_id}/certificates/{filename}".format(
+                base=self.base_url_ver, listener_id=FAKE_UUID_1,
                 filename=FAKE_PEM_FILENAME), status_code=404,
             headers={'content-type': 'application/json'})
         self.driver.delete_cert_pem(self.amp, FAKE_UUID_1,
@@ -1154,9 +1055,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_delete_cert_pem_unauthorized(self, m):
         m.delete(
-            "{base}/loadbalancer/{loadbalancer_id}/certificates/"
-            "{filename}".format(
-                base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
+            "{base}/listeners/{listener_id}/certificates/{filename}".format(
+                base=self.base_url_ver, listener_id=FAKE_UUID_1,
                 filename=FAKE_PEM_FILENAME), status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.delete_cert_pem,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME)
@@ -1164,9 +1064,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_delete_cert_pem_server_error(self, m):
         m.delete(
-            "{base}/loadbalancer/{loadbalancer_id}/certificates/"
-            "{filename}".format(
-                base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
+            "{base}/listeners/{listener_id}/certificates/{filename}".format(
+                base=self.base_url_ver, listener_id=FAKE_UUID_1,
                 filename=FAKE_PEM_FILENAME), status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.delete_cert_pem,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME)
@@ -1174,9 +1073,8 @@ class TestAmphoraAPIClientTest(base.TestCase):
     @requests_mock.mock()
     def test_delete_cert_pem_service_unavailable(self, m):
         m.delete(
-            "{base}/loadbalancer/{loadbalancer_id}/certificates/"
-            "{filename}".format(
-                base=self.base_url_ver, loadbalancer_id=FAKE_UUID_1,
+            "{base}/listeners/{listener_id}/certificates/{filename}".format(
+                base=self.base_url_ver, listener_id=FAKE_UUID_1,
                 filename=FAKE_PEM_FILENAME), status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.delete_cert_pem,
                           self.amp, FAKE_UUID_1, FAKE_PEM_FILENAME)
@@ -1185,10 +1083,10 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_config(self, m):
         config = {"name": "fake_config"}
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
+            "{base}/listeners/{"
+            "amphora_id}/{listener_id}/haproxy".format(
                 amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+                listener_id=FAKE_UUID_1),
             json=config)
         self.driver.upload_config(self.amp, FAKE_UUID_1,
                                   config)
@@ -1198,10 +1096,10 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_invalid_config(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
+            "{base}/listeners/{"
+            "amphora_id}/{listener_id}/haproxy".format(
                 amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+                listener_id=FAKE_UUID_1),
             status_code=400)
         self.assertRaises(exc.InvalidRequest, self.driver.upload_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1210,10 +1108,10 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_config_unauthorized(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
+            "{base}/listeners/{"
+            "amphora_id}/{listener_id}/haproxy".format(
                 amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+                listener_id=FAKE_UUID_1),
             status_code=401)
         self.assertRaises(exc.Unauthorized, self.driver.upload_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1222,10 +1120,10 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_config_server_error(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
+            "{base}/listeners/{"
+            "amphora_id}/{listener_id}/haproxy".format(
                 amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+                listener_id=FAKE_UUID_1),
             status_code=500)
         self.assertRaises(exc.InternalServerError, self.driver.upload_config,
                           self.amp, FAKE_UUID_1, config)
@@ -1234,10 +1132,10 @@ class TestAmphoraAPIClientTest(base.TestCase):
     def test_upload_config_service_unavailable(self, m):
         config = '{"name": "bad_config"}'
         m.put(
-            "{base}/loadbalancer/{"
-            "amphora_id}/{loadbalancer_id}/haproxy".format(
+            "{base}/listeners/{"
+            "amphora_id}/{listener_id}/haproxy".format(
                 amphora_id=self.amp.id, base=self.base_url_ver,
-                loadbalancer_id=FAKE_UUID_1),
+                listener_id=FAKE_UUID_1),
             status_code=503)
         self.assertRaises(exc.ServiceUnavailable, self.driver.upload_config,
                           self.amp, FAKE_UUID_1, config)
