@@ -26,23 +26,18 @@ class TestHealthManagerCMD(base.TestCase):
         super(TestHealthManagerCMD, self).setUp()
 
     @mock.patch('multiprocessing.Event')
-    @mock.patch('octavia.controller.healthmanager.'
-                'update_db.UpdateStatsDb')
-    @mock.patch('octavia.controller.healthmanager.'
-                'update_db.UpdateHealthDb')
     @mock.patch('octavia.amphorae.drivers.health.'
                 'heartbeat_udp.UDPStatusGetter')
-    def test_hm_listener(self, mock_getter, mock_health, mock_stats,
+    def test_hm_listener(self, mock_getter,
                          mock_event):
-        mock_event.is_set.side_effect = [False, False]
+        mock_event.is_set.side_effect = [False, False, True]
         getter_mock = mock.MagicMock()
         check_mock = mock.MagicMock()
         getter_mock.check = check_mock
         getter_mock.check.side_effect = [None, Exception('break')]
         mock_getter.return_value = getter_mock
-        self.assertRaisesRegexp(Exception, 'break',
-                                health_manager.hm_listener, mock_event)
-        mock_getter.assert_called_once_with(mock_health(), mock_stats())
+        health_manager.hm_listener(mock_event)
+        mock_getter.assert_called_once()
         self.assertEqual(2, getter_mock.check.call_count)
 
     @mock.patch('multiprocessing.Event')
@@ -94,8 +89,17 @@ class TestHealthManagerCMD(base.TestCase):
 
         mock_listener_proc.start.assert_called_once_with()
         mock_health_proc.start.assert_called_once_with()
-        mock_listener_proc.join.assert_called_once_with()
+        self.assertEqual(2, mock_listener_proc.join.call_count)
         mock_health_proc.join.assert_called_once_with()
-        mock_listener_proc.terminate.assert_called_once_with()
         mock_kill.assert_called_once_with(mock_health_proc.pid,
                                           signal.SIGINT)
+
+    @mock.patch('os.kill')
+    @mock.patch('oslo_config.cfg.CONF.mutate_config_files')
+    def test_handle_mutate_config(self, mock_mutate, mock_kill):
+        health_manager._handle_mutate_config(1, 2)
+
+        mock_mutate.assert_called_once()
+
+        calls = [mock.call(1, signal.SIGHUP), mock.call(2, signal.SIGHUP)]
+        mock_kill.assert_has_calls(calls)
