@@ -117,7 +117,8 @@ class TestUpdateHealthDb(base.TestCase):
 
     def _make_fake_lb_health_dict(self, listener=True, pool=True,
                                   health_monitor=True, members=1,
-                                  lb_prov_status=constants.ACTIVE):
+                                  lb_prov_status=constants.ACTIVE,
+                                  listener_protocol=constants.PROTOCOL_TCP):
 
         lb_ref = {'enabled': True, 'id': self.FAKE_UUID_1,
                   constants.OPERATING_STATUS: 'bogus',
@@ -141,7 +142,9 @@ class TestUpdateHealthDb(base.TestCase):
 
         if listener:
             listener_ref = {'listener-id-1': {
-                constants.OPERATING_STATUS: 'bogus'}}
+                constants.OPERATING_STATUS: 'bogus',
+                'protocol': listener_protocol,
+                'enabled': True}}
             lb_ref['listeners'] = listener_ref
 
         return lb_ref
@@ -182,6 +185,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {},
             "recv_time": time.time()
         }
@@ -198,6 +202,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {},
             "recv_time": time.time()
         }
@@ -215,6 +220,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {},
             "recv_time": time.time()
         }
@@ -231,6 +237,7 @@ class TestUpdateHealthDb(base.TestCase):
         hb_interval = cfg.CONF.health_manager.heartbeat_interval
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {},
             "recv_time": time.time() - hb_interval - 1  # extra -1 for buffer
         }
@@ -248,6 +255,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -270,9 +278,9 @@ class TestUpdateHealthDb(base.TestCase):
         self.session_mock.rollback.assert_called_once()
 
     def test_update_health_online(self):
-
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -318,10 +326,53 @@ class TestUpdateHealthDb(base.TestCase):
         self.hm.update_health(health, '192.0.2.1')
         self.assertTrue(not self.amphora_health_repo.replace.called)
 
+    def test_update_health_listener_disabled(self):
+        health = {
+            "id": self.FAKE_UUID_1,
+            "ver": 1,
+            "listeners": {
+                "listener-id-1": {"status": constants.OPEN, "pools": {
+                    "pool-id-1": {"status": constants.UP,
+                                  "members": {"member-id-1": constants.UP}
+                                  }
+                }
+                }
+            },
+            "recv_time": time.time()
+        }
+
+        lb_ref = self._make_fake_lb_health_dict()
+        lb_ref['listeners']['listener-id-2'] = {
+            'enabled': False, constants.OPERATING_STATUS: constants.OFFLINE}
+        self.amphora_repo.get_lb_for_health_update.return_value = lb_ref
+        self.hm.update_health(health, '192.0.2.1')
+        self.assertTrue(self.amphora_health_repo.replace.called)
+
+        # test listener, member
+        for listener_id, listener in six.iteritems(
+                health.get('listeners', {})):
+
+            self.listener_repo.update.assert_any_call(
+                self.session_mock, listener_id,
+                operating_status=constants.ONLINE)
+
+            for pool_id, pool in six.iteritems(listener.get('pools', {})):
+
+                self.hm.pool_repo.update.assert_any_call(
+                    self.session_mock, pool_id,
+                    operating_status=constants.ONLINE)
+
+                for member_id, member in six.iteritems(
+                        pool.get('members', {})):
+                    self.member_repo.update.assert_any_call(
+                        self.session_mock, member_id,
+                        operating_status=constants.ONLINE)
+
     def test_update_lb_pool_health_offline(self):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {}}
             },
@@ -349,6 +400,7 @@ class TestUpdateHealthDb(base.TestCase):
     def test_update_lb_multiple_listeners_one_error_pool(self):
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.DOWN,
@@ -369,7 +421,9 @@ class TestUpdateHealthDb(base.TestCase):
             'members': {'member-id-2': {constants.OPERATING_STATUS: 'bogus'}}}
 
         lb_ref['listeners']['listener-id-2'] = {
-            constants.OPERATING_STATUS: 'bogus'}
+            constants.OPERATING_STATUS: 'bogus',
+            'protocol': constants.PROTOCOL_TCP,
+            'enabled': True}
 
         self.amphora_repo.get_lb_for_health_update.return_value = lb_ref
         self.hm.update_health(health, '192.0.2.1')
@@ -395,6 +449,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -432,10 +487,54 @@ class TestUpdateHealthDb(base.TestCase):
                         self.session_mock, member_id,
                         operating_status=constants.ONLINE)
 
+    def test_update_v2_lb_and_list_pool_health_online(self):
+
+        health = {
+            "id": self.FAKE_UUID_1,
+            "ver": 2,
+            "listeners": {
+                "listener-id-1": {"status": constants.OPEN}
+            },
+            "pools": {
+                "pool-id-1:listener-id-1": {
+                    "status": constants.UP,
+                    "members": {"member-id-1": constants.UP}},
+                "pool-id-1:listener-id-1": {
+                    "status": constants.UP,
+                    "members": {"member-id-1": constants.UP}}},
+            "recv_time": time.time()
+        }
+
+        lb_ref = self._make_fake_lb_health_dict()
+        self.amphora_repo.get_lb_for_health_update.return_value = lb_ref
+        self.hm.update_health(health, '192.0.2.1')
+        self.assertTrue(self.amphora_health_repo.replace.called)
+
+        # test listener, member
+        for listener_id, listener in six.iteritems(
+                health.get('listeners', {})):
+
+            self.listener_repo.update.assert_any_call(
+                self.session_mock, listener_id,
+                operating_status=constants.ONLINE)
+
+        for pool_id, pool in six.iteritems(health.get('pools', {})):
+            # We should not double process a shared pool
+            self.hm.pool_repo.update.assert_called_once_with(
+                self.session_mock, 'pool-id-1',
+                operating_status=constants.ONLINE)
+
+            for member_id, member in six.iteritems(
+                    pool.get('members', {})):
+                self.member_repo.update.assert_any_call(
+                    self.session_mock, member_id,
+                    operating_status=constants.ONLINE)
+
     def test_update_pool_offline(self):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-5": {"status": constants.UP,
@@ -472,6 +571,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {
                     "status": constants.OPEN,
@@ -511,6 +611,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {
                     "status": constants.OPEN,
@@ -550,6 +651,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {
                     "status": constants.OPEN,
@@ -583,6 +685,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -625,6 +728,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -662,6 +766,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -704,6 +809,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -746,6 +852,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {
                     "status": constants.OPEN,
@@ -791,6 +898,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.FULL, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -840,6 +948,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.DOWN,
@@ -883,6 +992,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.FULL, "pools": {
                     "pool-id-1": {"status": constants.DOWN,
@@ -930,7 +1040,9 @@ class TestUpdateHealthDb(base.TestCase):
         for i in [1, 2, 3, 4, 5]:
 
             lb_ref['listeners']['listener-id-%s' % i] = {
-                constants.OPERATING_STATUS: 'bogus'}
+                constants.OPERATING_STATUS: 'bogus',
+                'protocol': constants.PROTOCOL_TCP,
+                'enabled': True}
 
             if i == 3:
                 members_dict = {'member-id-3': {
@@ -971,6 +1083,7 @@ class TestUpdateHealthDb(base.TestCase):
 
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {"status": constants.OPEN, "pools": {
                     "pool-id-1": {"status": constants.UP,
@@ -1021,9 +1134,21 @@ class TestUpdateHealthDb(base.TestCase):
                         self.session_mock, member_id,
                         operating_status=constants.ONLINE)
 
+    @mock.patch('stevedore.driver.DriverManager.driver')
+    def test_update_health_zombie(self, mock_driver):
+        health = {"id": self.FAKE_UUID_1, "listeners": {}}
+
+        self.amphora_repo.get_lb_for_health_update.return_value = None
+        amp_mock = mock.MagicMock()
+        self.amphora_repo.get.return_value = amp_mock
+        self.hm.update_health(health, '192.0.2.1')
+        mock_driver.delete.assert_called_once_with(
+            amp_mock.compute_id)
+
     def test_update_health_no_status_change(self):
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {
                 "listener-id-1": {
                     "status": constants.OPEN, "pools": {
@@ -1061,6 +1186,7 @@ class TestUpdateHealthDb(base.TestCase):
     def test_update_health_lb_admin_down(self):
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {},
             "recv_time": time.time()}
 
@@ -1139,11 +1265,16 @@ class TestUpdateHealthDb(base.TestCase):
 
         self.loadbalancer_repo.get.return_value = mock_lb
 
-        lb_ref = self._make_fake_lb_health_dict()
+        lb_ref = self._make_fake_lb_health_dict(
+            listener_protocol=constants.PROTOCOL_UDP)
         lb_ref['listeners']['listener-id-2'] = {
-            constants.OPERATING_STATUS: 'bogus'}
+            constants.OPERATING_STATUS: 'bogus',
+            'protocol': constants.PROTOCOL_UDP,
+            'enabled': True}
         lb_ref['listeners']['listener-id-3'] = {
-            constants.OPERATING_STATUS: 'bogus'}
+            constants.OPERATING_STATUS: 'bogus',
+            'protocol': constants.PROTOCOL_UDP,
+            'enabled': True}
 
         self.amphora_repo.get_lb_for_health_update.return_value = lb_ref
         self.hm.update_health(health, '192.0.2.1')
@@ -1154,6 +1285,7 @@ class TestUpdateHealthDb(base.TestCase):
     def test_update_health_no_db_lb(self):
         health = {
             "id": self.FAKE_UUID_1,
+            "ver": 1,
             "listeners": {},
             "recv_time": time.time()
         }
@@ -1178,30 +1310,71 @@ class TestUpdateHealthDb(base.TestCase):
         self.assertTrue(self.amphora_repo.get.called)
         self.assertTrue(self.amphora_health_repo.replace.called)
 
-    def test_update_listener_count_for_UDP(self):
+    def test_update_health_with_without_udp_listeners(self):
+        health = {
+            "id": self.FAKE_UUID_1,
+            "listeners": {
+                "listener-id-1": {"status": constants.OPEN, "pools": {
+                    "pool-id-1": {"status": constants.UP,
+                                  "members": {"member-id-1": constants.DOWN}
+                                  }
+                }}},
+            "recv_time": time.time()
+        }
 
+        # Test with a TCP listener
+        lb_ref = self._make_fake_lb_health_dict(
+            listener_protocol=constants.PROTOCOL_TCP)
+        self.amphora_repo.get_lb_for_health_update.return_value = lb_ref
+
+        self.hm.update_health(health, '192.0.2.1')
+        # We should have no calls to listener_repo.get, because we skip
+        # running the extra UDP function
+        self.assertFalse(self.listener_repo.get.called)
+
+        # Reset the mocks to try again
+        self.listener_repo.reset_mock()
+
+        # Test with a UDP listener
+        lb_ref = self._make_fake_lb_health_dict(
+            listener_protocol=constants.PROTOCOL_UDP)
+        self.amphora_repo.get_lb_for_health_update.return_value = lb_ref
+
+        self.hm.update_health(health, '192.0.2.1')
+        # This time we should have a call to listener_repo.get because the
+        # UDP helper function is triggered
+        self.assertTrue(self.listener_repo.get.called)
+
+    def test_update_listener_count_for_UDP(self):
         mock_lb, mock_listener1, mock_pool1, mock_members = (
             self._make_mock_lb_tree())
 
         mock_listener1.protocol = constants.PROTOCOL_TCP
 
-        self.hm.loadbalancer_repo.get.return_value = mock_lb
+        self.hm.listener_repo.get.return_value = mock_listener1
 
         # Test only TCP listeners
-        result = self.hm._update_listener_count_for_UDP('bogus_session', 1, 0)
+        lb_ref = self._make_fake_lb_health_dict(
+            listener_protocol=constants.PROTOCOL_TCP)
+        result = self.hm._update_listener_count_for_UDP(
+            'bogus_session', lb_ref, 0)
         self.assertEqual(0, result)
 
         # Test with a valid member
+        lb_ref = self._make_fake_lb_health_dict(
+            listener_protocol=constants.PROTOCOL_UDP)
         mock_listener1.protocol = constants.PROTOCOL_UDP
 
-        result = self.hm._update_listener_count_for_UDP('bogus_session', 1, 1)
+        result = self.hm._update_listener_count_for_UDP(
+            'bogus_session', lb_ref, 1)
         self.assertEqual(1, result)
 
         # Test with a disabled member
         mock_listener1.protocol = constants.PROTOCOL_UDP
         mock_members[0].enabled = False
 
-        result = self.hm._update_listener_count_for_UDP('bogus_session', 1, 1)
+        result = self.hm._update_listener_count_for_UDP(
+            'bogus_session', lb_ref, 1)
         self.assertEqual(0, result)
 
     def test_update_status_and_emit_event(self):
@@ -1297,6 +1470,7 @@ class TestUpdateStatsDb(base.TestCase):
 
         health = {
             "id": self.amphora_id,
+            "ver": 1,
             "listeners": {
                 self.listener_id: {
                     "status": constants.OPEN,
