@@ -49,6 +49,7 @@ _health_mon_mock = mock.MagicMock()
 _vip_mock = mock.MagicMock()
 _listener_mock = mock.MagicMock()
 _load_balancer_mock = mock.MagicMock()
+_load_balancer_mock.listeners = [_listener_mock]
 _member_mock = mock.MagicMock()
 _pool_mock = mock.MagicMock()
 _l7policy_mock = mock.MagicMock()
@@ -141,7 +142,8 @@ class TestControllerWorker(base.TestCase):
             assert_called_once_with(
                 'TEST',
                 store={constants.BUILD_TYPE_PRIORITY:
-                       constants.LB_CREATE_SPARES_POOL_PRIORITY}))
+                       constants.LB_CREATE_SPARES_POOL_PRIORITY,
+                       constants.FLAVOR: None}))
 
         _flow_mock.run.assert_called_once_with()
 
@@ -200,6 +202,7 @@ class TestControllerWorker(base.TestCase):
                                    mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        mock_health_mon_repo_get.side_effect = [None, _health_mon_mock]
 
         cw = controller_worker.ControllerWorker()
         cw.create_health_monitor(_health_mon_mock)
@@ -216,6 +219,7 @@ class TestControllerWorker(base.TestCase):
                                                _pool_mock}))
 
         _flow_mock.run.assert_called_once_with()
+        self.assertEqual(2, mock_health_mon_repo_get.call_count)
 
     @mock.patch('octavia.controller.worker.flows.'
                 'health_monitor_flows.HealthMonitorFlows.'
@@ -272,6 +276,7 @@ class TestControllerWorker(base.TestCase):
                                    mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        _health_mon_mock.provisioning_status = constants.PENDING_UPDATE
 
         cw = controller_worker.ControllerWorker()
         cw.update_health_monitor(_health_mon_mock.id,
@@ -310,6 +315,7 @@ class TestControllerWorker(base.TestCase):
                              mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        mock_listener_repo_get.side_effect = [None, _listener_mock]
 
         cw = controller_worker.ControllerWorker()
         cw.create_listener(LB_ID)
@@ -319,9 +325,10 @@ class TestControllerWorker(base.TestCase):
                                     store={constants.LOADBALANCER:
                                            _load_balancer_mock,
                                            constants.LISTENERS:
-                                           [_listener_mock]}))
+                                           _load_balancer_mock.listeners}))
 
         _flow_mock.run.assert_called_once_with()
+        self.assertEqual(2, mock_listener_repo_get.call_count)
 
     @mock.patch('octavia.controller.worker.flows.'
                 'listener_flows.ListenerFlows.get_delete_listener_flow',
@@ -370,6 +377,7 @@ class TestControllerWorker(base.TestCase):
                              mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        _listener_mock.provisioning_status = constants.PENDING_UPDATE
 
         cw = controller_worker.ControllerWorker()
         cw.update_listener(LB_ID, LISTENER_UPDATE_DICT)
@@ -414,9 +422,13 @@ class TestControllerWorker(base.TestCase):
         store = {
             constants.LOADBALANCER_ID: LB_ID,
             'update_dict': {'topology': constants.TOPOLOGY_SINGLE},
-            constants.BUILD_TYPE_PRIORITY: constants.LB_CREATE_NORMAL_PRIORITY
+            constants.BUILD_TYPE_PRIORITY: constants.LB_CREATE_NORMAL_PRIORITY,
+            constants.FLAVOR: None
         }
-        setattr(mock_lb_repo_get.return_value, 'listeners', [])
+        lb_mock = mock.MagicMock()
+        lb_mock.listeners = []
+        lb_mock.topology = constants.TOPOLOGY_SINGLE
+        mock_lb_repo_get.side_effect = [None, None, None, lb_mock]
 
         cw = controller_worker.ControllerWorker()
         cw.create_load_balancer(LB_ID)
@@ -426,6 +438,7 @@ class TestControllerWorker(base.TestCase):
         mock_taskflow_load.assert_called_with(
             mock_get_create_load_balancer_flow.return_value, store=store)
         mock_eng.run.assert_any_call()
+        self.assertEqual(4, mock_lb_repo_get.call_count)
 
     @mock.patch('octavia.controller.worker.flows.load_balancer_flows.'
                 'LoadBalancerFlows.get_create_load_balancer_flow',
@@ -456,8 +469,11 @@ class TestControllerWorker(base.TestCase):
         store = {
             constants.LOADBALANCER_ID: LB_ID,
             'update_dict': {'topology': constants.TOPOLOGY_ACTIVE_STANDBY},
-            constants.BUILD_TYPE_PRIORITY: constants.LB_CREATE_NORMAL_PRIORITY
+            constants.BUILD_TYPE_PRIORITY: constants.LB_CREATE_NORMAL_PRIORITY,
+            constants.FLAVOR: None
         }
+        setattr(mock_lb_repo_get.return_value, 'topology',
+                constants.TOPOLOGY_ACTIVE_STANDBY)
         setattr(mock_lb_repo_get.return_value, 'listeners', [])
 
         cw = controller_worker.ControllerWorker()
@@ -492,14 +508,16 @@ class TestControllerWorker(base.TestCase):
 
         listeners = [data_models.Listener(id='listener1'),
                      data_models.Listener(id='listener2')]
-        lb = data_models.LoadBalancer(id=LB_ID, listeners=listeners)
+        lb = data_models.LoadBalancer(id=LB_ID, listeners=listeners,
+                                      topology=constants.TOPOLOGY_SINGLE)
         mock_lb_repo_get.return_value = lb
         mock_eng = mock.Mock()
         mock_taskflow_load.return_value = mock_eng
         store = {
             constants.LOADBALANCER_ID: LB_ID,
             'update_dict': {'topology': constants.TOPOLOGY_SINGLE},
-            constants.BUILD_TYPE_PRIORITY: constants.LB_CREATE_NORMAL_PRIORITY
+            constants.BUILD_TYPE_PRIORITY: constants.LB_CREATE_NORMAL_PRIORITY,
+            constants.FLAVOR: None
         }
 
         cw = controller_worker.ControllerWorker()
@@ -542,21 +560,22 @@ class TestControllerWorker(base.TestCase):
 
         listeners = [data_models.Listener(id='listener1'),
                      data_models.Listener(id='listener2')]
-        lb = data_models.LoadBalancer(id=LB_ID, listeners=listeners)
+        lb = data_models.LoadBalancer(
+            id=LB_ID, listeners=listeners,
+            topology=constants.TOPOLOGY_ACTIVE_STANDBY)
         mock_lb_repo_get.return_value = lb
         mock_eng = mock.Mock()
         mock_taskflow_load.return_value = mock_eng
         store = {
             constants.LOADBALANCER_ID: LB_ID,
             'update_dict': {'topology': constants.TOPOLOGY_ACTIVE_STANDBY},
-            constants.BUILD_TYPE_PRIORITY: constants.LB_CREATE_NORMAL_PRIORITY
+            constants.BUILD_TYPE_PRIORITY: constants.LB_CREATE_NORMAL_PRIORITY,
+            constants.FLAVOR: None
         }
 
         cw = controller_worker.ControllerWorker()
         cw.create_load_balancer(LB_ID)
 
-        # mock_create_single_topology.assert_not_called()
-        # mock_create_active_standby_topology.assert_called_once()
         mock_get_create_load_balancer_flow.assert_called_with(
             topology=constants.TOPOLOGY_ACTIVE_STANDBY, listeners=lb.listeners)
         mock_taskflow_load.assert_called_with(
@@ -660,6 +679,7 @@ class TestControllerWorker(base.TestCase):
                                   mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        _load_balancer_mock.provisioning_status = constants.PENDING_UPDATE
 
         cw = controller_worker.ControllerWorker()
         change = 'TEST2'
@@ -697,6 +717,7 @@ class TestControllerWorker(base.TestCase):
                            mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        mock_member_repo_get.side_effect = [None, _member_mock]
 
         cw = controller_worker.ControllerWorker()
         cw.create_member(MEMBER_ID)
@@ -712,6 +733,7 @@ class TestControllerWorker(base.TestCase):
                                                _pool_mock}))
 
         _flow_mock.run.assert_called_once_with()
+        self.assertEqual(2, mock_member_repo_get.call_count)
 
     @mock.patch('octavia.controller.worker.flows.'
                 'member_flows.MemberFlows.get_delete_member_flow',
@@ -765,6 +787,7 @@ class TestControllerWorker(base.TestCase):
                            mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        _member_mock.provisioning_status = constants.PENDING_UPDATE
 
         cw = controller_worker.ControllerWorker()
         cw.update_member(MEMBER_ID, MEMBER_UPDATE_DICT)
@@ -833,6 +856,7 @@ class TestControllerWorker(base.TestCase):
                          mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        mock_pool_repo_get.side_effect = [None, _pool_mock]
 
         cw = controller_worker.ControllerWorker()
         cw.create_pool(POOL_ID)
@@ -846,6 +870,7 @@ class TestControllerWorker(base.TestCase):
                                                _load_balancer_mock}))
 
         _flow_mock.run.assert_called_once_with()
+        self.assertEqual(2, mock_pool_repo_get.call_count)
 
     @mock.patch('octavia.controller.worker.flows.'
                 'pool_flows.PoolFlows.get_delete_pool_flow',
@@ -897,6 +922,7 @@ class TestControllerWorker(base.TestCase):
                          mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        _pool_mock.provisioning_status = constants.PENDING_UPDATE
 
         cw = controller_worker.ControllerWorker()
         cw.update_pool(POOL_ID, POOL_UPDATE_DICT)
@@ -931,6 +957,7 @@ class TestControllerWorker(base.TestCase):
                              mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        mock_l7policy_repo_get.side_effect = [None, _l7policy_mock]
 
         cw = controller_worker.ControllerWorker()
         cw.create_l7policy(L7POLICY_ID)
@@ -944,6 +971,7 @@ class TestControllerWorker(base.TestCase):
                                                _load_balancer_mock}))
 
         _flow_mock.run.assert_called_once_with()
+        self.assertEqual(2, mock_l7policy_repo_get.call_count)
 
     @mock.patch('octavia.controller.worker.flows.'
                 'l7policy_flows.L7PolicyFlows.get_delete_l7policy_flow',
@@ -995,6 +1023,7 @@ class TestControllerWorker(base.TestCase):
                              mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        _l7policy_mock.provisioning_status = constants.PENDING_UPDATE
 
         cw = controller_worker.ControllerWorker()
         cw.update_l7policy(L7POLICY_ID, L7POLICY_UPDATE_DICT)
@@ -1029,6 +1058,7 @@ class TestControllerWorker(base.TestCase):
                            mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        mock_l7rule_repo_get.side_effect = [None, _l7rule_mock]
 
         cw = controller_worker.ControllerWorker()
         cw.create_l7rule(L7RULE_ID)
@@ -1043,6 +1073,7 @@ class TestControllerWorker(base.TestCase):
                                                _load_balancer_mock}))
 
         _flow_mock.run.assert_called_once_with()
+        self.assertEqual(2, mock_l7rule_repo_get.call_count)
 
     @mock.patch('octavia.controller.worker.flows.'
                 'l7rule_flows.L7RuleFlows.get_delete_l7rule_flow',
@@ -1095,6 +1126,7 @@ class TestControllerWorker(base.TestCase):
                            mock_amp_repo_get):
 
         _flow_mock.reset_mock()
+        _l7rule_mock.provisioning_status = constants.PENDING_UPDATE
 
         cw = controller_worker.ControllerWorker()
         cw.update_l7rule(L7RULE_ID, L7RULE_UPDATE_DICT)
@@ -1112,6 +1144,8 @@ class TestControllerWorker(base.TestCase):
 
         _flow_mock.run.assert_called_once_with()
 
+    @mock.patch('octavia.db.repositories.FlavorRepository.'
+                'get_flavor_metadata_dict', return_value={})
     @mock.patch('octavia.controller.worker.flows.'
                 'amphora_flows.AmphoraFlows.get_failover_flow',
                 return_value=_flow_mock)
@@ -1119,6 +1153,7 @@ class TestControllerWorker(base.TestCase):
     def test_failover_amphora(self,
                               mock_update,
                               mock_get_failover_flow,
+                              mock_get_flavor_meta,
                               mock_api_get_session,
                               mock_dyn_log_listener,
                               mock_taskflow_load,
@@ -1143,7 +1178,8 @@ class TestControllerWorker(base.TestCase):
                        constants.LOADBALANCER_ID:
                            _amphora_mock.load_balancer_id,
                        constants.BUILD_TYPE_PRIORITY:
-                           constants.LB_CREATE_FAILOVER_PRIORITY
+                           constants.LB_CREATE_FAILOVER_PRIORITY,
+                       constants.FLAVOR: {}
                        }))
 
         _flow_mock.run.assert_called_once_with()
@@ -1226,9 +1262,9 @@ class TestControllerWorker(base.TestCase):
         mock_perform_amp_failover.assert_called_once_with(
             amphora, constants.LB_CREATE_FAILOVER_PRIORITY)
 
-    @mock.patch('octavia.db.repositories.AmphoraHealthRepository.update')
+    @mock.patch('octavia.db.repositories.AmphoraHealthRepository.delete')
     def test_failover_deleted_amphora(self,
-                                      mock_update,
+                                      mock_delete,
                                       mock_api_get_session,
                                       mock_dyn_log_listener,
                                       mock_taskflow_load,
@@ -1249,7 +1285,7 @@ class TestControllerWorker(base.TestCase):
         cw = controller_worker.ControllerWorker()
         cw._perform_amphora_failover(mock_amphora, 10)
 
-        mock_update.assert_called_with(_db_session, AMP_ID, busy=True)
+        mock_delete.assert_called_with(_db_session, amphora_id=AMP_ID)
         mock_taskflow_load.assert_not_called()
 
     @mock.patch('octavia.controller.worker.'
@@ -1299,6 +1335,8 @@ class TestControllerWorker(base.TestCase):
         mock_update.assert_called_with(_db_session, 123,
                                        provisioning_status=constants.ERROR)
 
+    @mock.patch('octavia.db.repositories.FlavorRepository.'
+                'get_flavor_metadata_dict', return_value={})
     @mock.patch('octavia.controller.worker.flows.'
                 'amphora_flows.AmphoraFlows.get_failover_flow',
                 return_value=_flow_mock)
@@ -1308,8 +1346,9 @@ class TestControllerWorker(base.TestCase):
     @mock.patch('octavia.db.repositories.LoadBalancerRepository.update')
     def test_failover_amphora_anti_affinity(self,
                                             mock_update,
-                                            mock_get_update_listener_flow,
                                             mock_get_lb_for_amphora,
+                                            mock_get_update_listener_flow,
+                                            mock_get_flavor_meta,
                                             mock_api_get_session,
                                             mock_dyn_log_listener,
                                             mock_taskflow_load,
@@ -1338,6 +1377,7 @@ class TestControllerWorker(base.TestCase):
                        constants.BUILD_TYPE_PRIORITY:
                            constants.LB_CREATE_FAILOVER_PRIORITY,
                        constants.SERVER_GROUP_ID: "123",
+                       constants.FLAVOR: {}
                        }))
 
         _flow_mock.run.assert_called_once_with()
@@ -1369,3 +1409,58 @@ class TestControllerWorker(base.TestCase):
                                         constants.AMPHORA_ID:
                                             _amphora_mock.id}))
         _flow_mock.run.assert_called_once_with()
+
+    @mock.patch('octavia.db.repositories.FlavorRepository.'
+                'get_flavor_metadata_dict')
+    @mock.patch('octavia.db.repositories.AmphoraRepository.get_lb_for_amphora')
+    @mock.patch('octavia.controller.worker.flows.'
+                'amphora_flows.AmphoraFlows.update_amphora_config_flow',
+                return_value=_flow_mock)
+    def test_update_amphora_agent_config(self,
+                                         mock_update_flow,
+                                         mock_get_lb_for_amp,
+                                         mock_flavor_meta,
+                                         mock_api_get_session,
+                                         mock_dyn_log_listener,
+                                         mock_taskflow_load,
+                                         mock_pool_repo_get,
+                                         mock_member_repo_get,
+                                         mock_l7rule_repo_get,
+                                         mock_l7policy_repo_get,
+                                         mock_listener_repo_get,
+                                         mock_lb_repo_get,
+                                         mock_health_mon_repo_get,
+                                         mock_amp_repo_get):
+        _flow_mock.reset_mock()
+        mock_lb = mock.MagicMock()
+        mock_lb.flavor_id = 'vanilla'
+        mock_get_lb_for_amp.return_value = mock_lb
+        mock_flavor_meta.return_value = {'test': 'dict'}
+        cw = controller_worker.ControllerWorker()
+        cw.update_amphora_agent_config(AMP_ID)
+
+        mock_amp_repo_get.assert_called_once_with(_db_session, id=AMP_ID)
+        mock_get_lb_for_amp.assert_called_once_with(_db_session, AMP_ID)
+        mock_flavor_meta.assert_called_once_with(_db_session, 'vanilla')
+        (base_taskflow.BaseTaskFlowEngine._taskflow_load.
+         assert_called_once_with(_flow_mock,
+                                 store={constants.AMPHORA: _amphora_mock,
+                                        constants.FLAVOR: {'test': 'dict'}}))
+        _flow_mock.run.assert_called_once_with()
+
+        # Test with no flavor
+        _flow_mock.reset_mock()
+        mock_amp_repo_get.reset_mock()
+        mock_get_lb_for_amp.reset_mock()
+        mock_flavor_meta.reset_mock()
+        base_taskflow.BaseTaskFlowEngine._taskflow_load.reset_mock()
+        mock_lb.flavor_id = None
+        cw.update_amphora_agent_config(AMP_ID)
+        mock_amp_repo_get.assert_called_once_with(_db_session, id=AMP_ID)
+        mock_get_lb_for_amp.assert_called_once_with(_db_session, AMP_ID)
+        mock_flavor_meta.assert_not_called()
+        (base_taskflow.BaseTaskFlowEngine._taskflow_load.
+         assert_called_once_with(_flow_mock,
+                                 store={constants.AMPHORA: _amphora_mock,
+                                        constants.FLAVOR: {}}))
+        _flow_mock.run.assert_called_once_with()
